.. include:: ../../README.rst

Dependencies
------------

The `argh` library is supported (and tested unless otherwise specified)
on the following versions of Python: 3.8, 3.9, 3.10, 3.11.

If you need support for ancient Pythons, please use the following versions
of Argh (the numeric puns were semi-intentional):

* Python 2.6 — Argh 0.26.x.
* Python 2.7 — Argh 0.27.x.

Why this one?
-------------

See :doc:`similar`.

Details
-------

.. toctree::
   :maxdepth: 2

   tutorial
   reference
   cookbook
   similar
   projects
   subparsers
   contributors
   changes

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
